==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/test/t_TruncatedNormalFactory_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_TruncatedNormalFactory_std.cxx
 *  @brief The test file of class TruncatedNormal for standard methods
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: t_TruncatedNormalFactory_std.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "TruncatedNormalFactory.hxx"
#include "TruncatedNormal.hxx"
#include "Distribution.hxx"
#include "NumericalSample.hxx"
#include "NumericalPoint.hxx"
#include "PlatformInfo.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Common;
using namespace OT::Base::Stat;
using namespace OT::Base::Type;
using namespace OT::Uncertainty::Distribution;
using namespace OT::Uncertainty::Model;


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();  

  try {
    NumericalPoint mu(4, 0.0);
    NumericalPoint sigma(4, 1.0);
    NumericalPoint a(4);
    NumericalPoint b(4);
    a[0] = -4.0;
    b[0] = 4.0;
    a[1] = -1.0;
    b[1] = 4.0;
    a[2] = 1.0;
    b[2] = 2.0;
    a[3] = 3.0;
    b[3] = 6.0;
    PlatformInfo::SetNumericalPrecision(4);
    for (UnsignedLong i = 0; i < 4; i++)
      {
	TruncatedNormal distribution(mu[i], sigma[i], a[i], b[i]);
	UnsignedLong size(10000);
	NumericalSample sample(distribution.getNumericalSample(size));
	TruncatedNormalFactory factory;
	Distribution estimatedDistribution(factory.buildImplementation(sample));
	fullprint << "Distribution          =" << distribution << std::endl;
	fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
      }
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_0.15.orig.tar.gz: openturns-0.15/lib/test/t_TruncatedNormalFactory_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_TruncatedNormalFactory_std.cxx
 *  @brief The test file of class TruncatedNormal for standard methods
 *
 *  (C) Copyright 2005-2011 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2011-07-28 18:31:43 +0200 (Thu, 28 Jul 2011) $
 *  Id:      $Id: t_TruncatedNormalFactory_std.cxx 2046 2011-07-28 16:31:43Z schueller $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "TruncatedNormalFactory.hxx"
#include "TruncatedNormal.hxx"
#include "Distribution.hxx"
#include "NumericalSample.hxx"
#include "NumericalPoint.hxx"
#include "PlatformInfo.hxx"
#include "CovarianceMatrix.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Stat;
using namespace OT::Base::Type;
using namespace OT::Uncertainty::Distribution;
using namespace OT::Uncertainty::Model;


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try {
    NumericalPoint mu(4, 0.0);
    NumericalPoint sigma(4, 1.0);
    NumericalPoint a(4);
    NumericalPoint b(4);
    a[0] = -4.0;
    b[0] = 4.0;
    a[1] = -1.0;
    b[1] = 4.0;
    a[2] = 1.0;
    b[2] = 2.0;
    a[3] = 3.0;
    b[3] = 6.0;
    PlatformInfo::SetNumericalPrecision(4);
    for (UnsignedLong i = 0; i < 4; i++)
      {
        TruncatedNormal distribution(mu[i], sigma[i], a[i], b[i]);
        UnsignedLong size(10000);
        NumericalSample sample(distribution.getNumericalSample(size));
        TruncatedNormalFactory factory;
        CovarianceMatrix covariance;
        // Distribution estimatedDistribution(factory.build(sample, covariance));
        Distribution estimatedDistribution(factory.build(sample));
        fullprint << "Distribution          =" << distribution << std::endl;
        fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
        // fullprint << "Covariance=" << covariance << std::endl;
        estimatedDistribution = factory.build();
        fullprint << "Default distribution=" << estimatedDistribution << std::endl;
        estimatedDistribution = factory.build(distribution.getParametersCollection());
        fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
      }
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
